.. toctree::
   :caption: Getting Started
   :hidden:

   Introduction <self>

.. toctree::
   :caption: Reference
   :maxdepth: -1
   :hidden:

   API <autoapi/pyrho/index>

Introduction
============

.. mdinclude:: ../../README.md
   :start-line: 4
